#!/usr/bin/env bash

source ./utils.sh;
type -p DFTRES &>/dev/null ||
	(echo "DFTRES not found in the environment! Aborting" && exit 1);

export RESULTS_DIR=$RESULTS_DIR;
DIR="`make_fresh_results_dir`";
echo "Storing results in $DIR";

for MNAME in "${MODEL_NAMES[@]}"; do
	echo;
	echo "Experiments on model \"$MNAME\"";
	MODEL="$MODELS_DIR/$MNAME.$MODELS_EXT";
	# Reliability
	LOG_REL="$DIR/${MNAME}_rel.dat";
	echo -e "# mtime\tunreliability\tprecision\trelative error\truntime (s)" > $LOG_REL;
	for T in "${REL_TIMES[@]}"; do
		echo "  Reliability  @ $T";
		LOG="${LOG_REL%.*}_$T.log";
		DFTRES -s $SEED --relErr $ERROR -r $T $MODEL &> $LOG;
		get_results $T $LOG >> $LOG_REL;
	done
	# Availability
	LOG_AVA="$DIR/${MNAME}_ava.dat";
	echo -e "# rtime\tunavailability\tprecision\trelative error\truntime (s)" > $LOG_AVA;
	for T in "${AVA_TIMES[@]}"; do
		echo "  Availability # $T";
		LOG="${LOG_AVA%.*}_$T.log";
		timeout $T DFTRES -s $SEED --relErr 1e-42 -a $MODEL &>$LOG;
		sleep 2;  # await log printing after timeout interrupt
		get_results $T $LOG >> $LOG_AVA;
	done
done;

echo;
echo "Results stored in $DIR";
echo "Finished all experiments on `date "+%b_%d @ %T"`";

exit 0;
