#!/bin/bash

source ./utils.sh;

LAST_RESULTS="${RESULTS_DIR}/Mai02_16:19:37";
DATA_DIR="${LAST_RESULTS}";

bc_compute() {
	local RESULT=$(printf "scale=60\n$1\n" | bc -l);
	# Remove trailing zeros
	case "$RESULT" in
		*.*) # Contains a decimal point
			RESULT=$(echo "$RESULT" | sed -e 's/\.\?0\+$//g');
		;;
	esac
	echo $RESULT;
}

summarize_category() {
	declare -a TAGS=($@);
	local SUFFIX="$1";
	local TAGNAME="$2";
	local TAGS=("${TAGS[@]:2}");
	for model in "${MODEL_NAMES[@]}"; do
		local DATA_FILE="$DATA_DIR/${model}_$SUFFIX.dat";
		echo "$TAGNAME $SUFFIX prec runtime scale scaled_$SUFFIX scaled_prec sqrt_$SUFFIX rel_prec" > "$DATA_FILE";
		local SCALE=1000;
		local PREC_SCALE=1000;
		for tag in "${TAGS[@]}"; do
			local REL=$(grep CI "$LAST_RESULTS/${model}_${SUFFIX}_$tag.log" | sed -e 's/.*= //g' | sed -e 's/ +.*//g');
			if [ -z $REL ]; then
				continue;
			fi
			local EXPONENT=$(echo $REL | grep -o 'E.*' | grep -o '[[:digit:]]\+');
			if [ "$EXPONENT" -lt "$SCALE" ]; then
				SCALE=$EXPONENT;
			fi
			
			local PREC=$(grep CI "$LAST_RESULTS/${model}_${SUFFIX}_$tag.log" | sed -e 's/.*+\/- //g');
			local EXPONENT=$(echo $PREC | grep -o 'E.*' | grep -o '[[:digit:]]\+');
			if [ "$EXPONENT" -lt "$PREC_SCALE" ]; then
				PREC_SCALE=$EXPONENT;
			fi
		done
		local SCALE=$(( $SCALE - 1 ))
		local PREC_SCALE=$(( $PREC_SCALE - 1 ))
		echo "\$10^{-$SCALE}\$" > "$DATA_DIR/${model}_$SUFFIX.scale";
		echo "\$10^{-$PREC_SCALE}\$" > "$DATA_DIR/${model}_$SUFFIX.prec_scale";
		for tag in "${TAGS[@]}"; do
			REL=$(grep CI "$LAST_RESULTS/${model}_${SUFFIX}_$tag.log" | sed -e 's/.*= //g' | sed -e 's/ +.*//g');
			if [ -z $REL ]; then
				echo $tag 0 0 $RUNTIME 0 0 0 >> "$DATA_FILE";
				continue;
			fi
			local PREC=$(grep CI "$LAST_RESULTS/${model}_${SUFFIX}_$tag.log" | sed -e 's/.*+\/- //g');
			local REL_NUM=$(echo $REL | sed -e 's/E/*10^/g');
			local PREC_NUM=$(echo $PREC | sed -e 's/E/*10^/g');
			local SCALED_REL=$(bc_compute "$REL_NUM * 10^$SCALE");
			local SCALED_PREC=$(bc_compute "$PREC_NUM * 10^$PREC_SCALE");
			# Divide the exponent by 10, because latex has issues with plotting really large numbers
			local SQRT_REL=$(bc_compute "e(l($REL_NUM) / 10)");
			local REL_PREC=$(bc_compute "($PREC_NUM) / ($REL_NUM)");
			local RUNTIME=$(grep 'Total time' "$LAST_RESULTS/${model}_${SUFFIX}_$tag.log" | grep -o '[[:digit:]]\+\(\.[[:digit:]]\+\)\?');
			if [[ $TAGNAME = "rtime" ]]; then  # I know... f**k!
				tag="`make_time_seconds $tag`";
			fi
			echo $tag $REL $PREC $RUNTIME $SCALE $SCALED_REL $SCALED_PREC $SQRT_REL $REL_PREC >> "$DATA_FILE";
		done
	done
}

# declare -a MISSION_TIMES_REL=("${REL_TIMES[@]}");
# declare -a RUN_TIMES_AVA=("`make_time_seconds "${AVA_TIMES[@]}"`");
# summarize_category rel mtime "${MISSION_TIMES_REL[@]}";
# summarize_category ava rtime "${RUN_TIMES_AVA[@]}";

summarize_category rel mtime "${REL_TIMES[@]}";
summarize_category ava rtime "${AVA_TIMES[@]}";

exit 0;
