
MODEL_NAMES=(
	rbc
	ftpp
	hecs
	cabinets
);

MODELS_EXT="dft";
MODELS_DIR="../models";
RESULTS_DIR="../results";

ERROR="0.05";  # relative error for reliability

SEED=42;  # RNG seed

# Mission times for unreliability queries
REL_TIMES=(
	1.0
	0.5
	0.1
	0.05
	0.01
	0.005
	0.001
);

# Max runtime for unavailability queries
AVA_TIMES=(
	30s
	1m
	2m
	5m
	10m
);

# Create a fresh directory to store results into,
# prepending the value of variable RESULTS_DIR, if any
make_fresh_results_dir() {
	if [ -z ${RESULTS_DIR} ]; then
		local RESULTS_DIR=".";
	fi
	while
		local NOW=`date +%b%d_%T`
		[ -e "${RESULTS_DIR}/${NOW}" ]
	do
		sleep 1;
	done
	mkdir -p "${RESULTS_DIR}/${NOW}";
	echo "${RESULTS_DIR}/${NOW}";
}

# Turn timeout specification into (numeric) seconds
# E.g. 12s --> 12, 2m --> 120, 1h --> 3600, 14 --> 14
make_time_seconds() {
	declare -a STIMES=();
	for T in "$@"; do
		TSPEC="${T: -1}";  # last character can be 's', 'm', 'h', or number
		if [[ $TSPEC =~ [0-9] ]]; then
			STIMES+=( $T );  # number: assume seconds
		elif [[ $TSPEC = s ]]; then
			STIMES+=( ${T:0: -1} );
		elif [[ $TSPEC = m ]]; then
			STIMES+=( $(( 60*${T:0: -1} )) );
		elif [[ $TSPEC = h ]]; then
			STIMES+=( $(( 3600*${T:0: -1} )) );
		fi
	done
	echo "${STIMES[@]}";
}

get_runtime() {
	grep "Total time" $1 | awk '{ print $3 }';
}

get_CI() {
	grep "CI" $1 | awk '{ print $2,$3 }';
}

get_estimate() {
	grep "point estimate" "$1" | awk '{ gsub(",",""); printf("%.2e",$3) }';
}

get_precision() {
	grep "CI" $1 | awk '{ gsub(",",""); printf("%.2e",$NF) }';
}

get_rel_error() {
	echo "`get_estimate $1` `get_precision $1`" | awk '{ printf("%.2e",$2/$1) }';
}

get_results() {
	echo -e "$1\t`get_estimate $2`\t`get_precision $2`\t`get_rel_error $2`\t`get_runtime $2`";
}

return 0;
